svarog.dispatchers package
==========================

Submodules
----------

svarog.dispatchers.functional module
------------------------------------

.. automodule:: svarog.dispatchers.functional
   :members:
   :undoc-members:
   :show-inheritance:

svarog.dispatchers.multi module
-------------------------------

.. automodule:: svarog.dispatchers.multi
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: svarog.dispatchers
   :members:
   :undoc-members:
   :show-inheritance:
